California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 033 - CHANGES LAW TO ALLOW AUTO INSURANCE COMPANIES TO SET PRICES BASED ON A DRIVER'S HISTORY OF INSURANCE COVERAGE. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350907 | GREENLINING ACTION FUND FOR YES ON PROPOSITION 33, WITH MAJOR FUNDING PROVIDED BY MERCURY INSURANCE CHAIRMAN GEORGE JOSEPH | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1340976 | 2012 AUTO INSURANCE DISCOUNT ACT, YES ON PROPOSITION 33, SPONSORED BY THE AMERICAN AGENTS ALLIANCE WITH SUPPORT FROM CALIFORNIA INSURANCE PROVIDERS FOR COMPETITIVE PRICES AND CONSUMER DISCOUNTS, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322520 | CONSUMER WATCHDOG CAMPAIGN TO STOP PROP 33, THE INSURANCE INDUSTRY DECEPTION, MAJOR FUNDING BY CALIFORNIA NURSES ASSOCIATION'S QUALITY HEALTH CARE COMMITTEE & CONSUMER WATCHDOG CAMPAIGN COMMITTEE | OPPOSE